@@ -8,7 +8,7 @@ from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.exceptions import ImproperlyConfigured
 
-from notification.backends.base import BaseNotificationBackend, notify
+from notification.base import BaseNotificationBackend, notify
 
 
 class AliyunSMSNotificationBackend(BaseNotificationBackend):
